How to install — GsuiteToMd 0.99 documentation

GsuiteToMd is a library built on top of PyDrive that offers a simple way to convert Documents store in Google Drive in markdown.

# How to install

You can install GsuiteToMd with regular `pip` command.

    $ pip install GsuiteToMd

## Basic example

    python -m gstomd --folder_id "myfolderid"

This command will extract all Google Documents files located in root folder and its subfolders as markdown documents. The folder tree will be created in a local folder named “gstomd_extract”.

For example, for this google drive content :

    Mydrive
    ├── folder A (id="idofthefolderA")
        ├── gdoc1
        ├── gdoc2
        ├── folder B
            ├── gdoc3
    ├── folder C
    ├── ...

The result will be

    .
    ├── gstomd_extract
        ├── folderA
            ├── gdoc1
                ├── gdoc1.md
                ├── images
                    ├── image1.png
                    ├── image2.png
            ├── gdoc2
                ├── gdoc2.md
                ├── images
                    ├── image1.png
        ├── folderB
            ├── gdoc3
                ├── gdoc3.md
                ├── images
                    ├── image1.png